# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialServerObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "server_name": "str",
        "region_id": "float",
        "server_public_ipv4": "str",
        "server_public_ipv6": "str",
        "server_config_ipv4": "str",
        "server_config_ipv6": "str",
        "server_ipv6_encaps": "str",
        "server_ipv6_start": "str",
        "server_ipv6_end": "str",
        "server_ipv6_serialized": "list[str]",
        "server_gateway_ipv4": "str",
        "server_gateway_ipv6": "str",
        "provider_id": "float",
        "topology_id": "float",
        "server_sr_software": "ServerSrSoftware",
        "server_is_transit": "bool",
        "server_is_edge": "bool",
        "server_status": "Status",
        "server_status_reason": "str",
        "server_location_lat": "float",
        "server_location_lon": "float",
        "server_location_city": "str",
        "server_proxy_required": "bool",
        "server_tap_ipv4_cidr": "str",
        "server_tap_host_ipv4_cidr": "str",
        "server_tap_host_bridge": "str",
        "server_public_tap_host_ipv4": "str",
        "server_public_tap_vpp_ipv4": "str",
        "server_agent_status": "ServerAgentStatus",
        "server_agent_key": "str",
        "vpn_id": "float",
        "server_skip_configuration": "bool",
    }

    attribute_map = {
        "server_name": "server_name",
        "region_id": "region_id",
        "server_public_ipv4": "server_public_ipv4",
        "server_public_ipv6": "server_public_ipv6",
        "server_config_ipv4": "server_config_ipv4",
        "server_config_ipv6": "server_config_ipv6",
        "server_ipv6_encaps": "server_ipv6_encaps",
        "server_ipv6_start": "server_ipv6_start",
        "server_ipv6_end": "server_ipv6_end",
        "server_ipv6_serialized": "server_ipv6_serialized",
        "server_gateway_ipv4": "server_gateway_ipv4",
        "server_gateway_ipv6": "server_gateway_ipv6",
        "provider_id": "provider_id",
        "topology_id": "topology_id",
        "server_sr_software": "server_sr_software",
        "server_is_transit": "server_is_transit",
        "server_is_edge": "server_is_edge",
        "server_status": "server_status",
        "server_status_reason": "server_status_reason",
        "server_location_lat": "server_location_lat",
        "server_location_lon": "server_location_lon",
        "server_location_city": "server_location_city",
        "server_proxy_required": "server_proxy_required",
        "server_tap_ipv4_cidr": "server_tap_ipv4_cidr",
        "server_tap_host_ipv4_cidr": "server_tap_host_ipv4_cidr",
        "server_tap_host_bridge": "server_tap_host_bridge",
        "server_public_tap_host_ipv4": "server_public_tap_host_ipv4",
        "server_public_tap_vpp_ipv4": "server_public_tap_vpp_ipv4",
        "server_agent_status": "server_agent_status",
        "server_agent_key": "server_agent_key",
        "vpn_id": "vpn_id",
        "server_skip_configuration": "server_skip_configuration",
    }

    def __init__(
        self,
        server_name=None,
        region_id=None,
        server_public_ipv4=None,
        server_public_ipv6=None,
        server_config_ipv4=None,
        server_config_ipv6=None,
        server_ipv6_encaps=None,
        server_ipv6_start=None,
        server_ipv6_end=None,
        server_ipv6_serialized=None,
        server_gateway_ipv4=None,
        server_gateway_ipv6=None,
        provider_id=None,
        topology_id=None,
        server_sr_software=None,
        server_is_transit=None,
        server_is_edge=None,
        server_status=None,
        server_status_reason=None,
        server_location_lat=None,
        server_location_lon=None,
        server_location_city=None,
        server_proxy_required=None,
        server_tap_ipv4_cidr=None,
        server_tap_host_ipv4_cidr=None,
        server_tap_host_bridge=None,
        server_public_tap_host_ipv4=None,
        server_public_tap_vpp_ipv4=None,
        server_agent_status=None,
        server_agent_key=None,
        vpn_id=None,
        server_skip_configuration=None,
    ):  # noqa: E501
        """TsoaPartialServerObject_ - a model defined in Swagger"""  # noqa: E501
        self._server_name = None
        self._region_id = None
        self._server_public_ipv4 = None
        self._server_public_ipv6 = None
        self._server_config_ipv4 = None
        self._server_config_ipv6 = None
        self._server_ipv6_encaps = None
        self._server_ipv6_start = None
        self._server_ipv6_end = None
        self._server_ipv6_serialized = None
        self._server_gateway_ipv4 = None
        self._server_gateway_ipv6 = None
        self._provider_id = None
        self._topology_id = None
        self._server_sr_software = None
        self._server_is_transit = None
        self._server_is_edge = None
        self._server_status = None
        self._server_status_reason = None
        self._server_location_lat = None
        self._server_location_lon = None
        self._server_location_city = None
        self._server_proxy_required = None
        self._server_tap_ipv4_cidr = None
        self._server_tap_host_ipv4_cidr = None
        self._server_tap_host_bridge = None
        self._server_public_tap_host_ipv4 = None
        self._server_public_tap_vpp_ipv4 = None
        self._server_agent_status = None
        self._server_agent_key = None
        self._vpn_id = None
        self._server_skip_configuration = None
        self.discriminator = None
        if server_name is not None:
            self.server_name = server_name
        if region_id is not None:
            self.region_id = region_id
        if server_public_ipv4 is not None:
            self.server_public_ipv4 = server_public_ipv4
        if server_public_ipv6 is not None:
            self.server_public_ipv6 = server_public_ipv6
        if server_config_ipv4 is not None:
            self.server_config_ipv4 = server_config_ipv4
        if server_config_ipv6 is not None:
            self.server_config_ipv6 = server_config_ipv6
        if server_ipv6_encaps is not None:
            self.server_ipv6_encaps = server_ipv6_encaps
        if server_ipv6_start is not None:
            self.server_ipv6_start = server_ipv6_start
        if server_ipv6_end is not None:
            self.server_ipv6_end = server_ipv6_end
        if server_ipv6_serialized is not None:
            self.server_ipv6_serialized = server_ipv6_serialized
        if server_gateway_ipv4 is not None:
            self.server_gateway_ipv4 = server_gateway_ipv4
        if server_gateway_ipv6 is not None:
            self.server_gateway_ipv6 = server_gateway_ipv6
        if provider_id is not None:
            self.provider_id = provider_id
        if topology_id is not None:
            self.topology_id = topology_id
        if server_sr_software is not None:
            self.server_sr_software = server_sr_software
        if server_is_transit is not None:
            self.server_is_transit = server_is_transit
        if server_is_edge is not None:
            self.server_is_edge = server_is_edge
        if server_status is not None:
            self.server_status = server_status
        if server_status_reason is not None:
            self.server_status_reason = server_status_reason
        if server_location_lat is not None:
            self.server_location_lat = server_location_lat
        if server_location_lon is not None:
            self.server_location_lon = server_location_lon
        if server_location_city is not None:
            self.server_location_city = server_location_city
        if server_proxy_required is not None:
            self.server_proxy_required = server_proxy_required
        if server_tap_ipv4_cidr is not None:
            self.server_tap_ipv4_cidr = server_tap_ipv4_cidr
        if server_tap_host_ipv4_cidr is not None:
            self.server_tap_host_ipv4_cidr = server_tap_host_ipv4_cidr
        if server_tap_host_bridge is not None:
            self.server_tap_host_bridge = server_tap_host_bridge
        if server_public_tap_host_ipv4 is not None:
            self.server_public_tap_host_ipv4 = server_public_tap_host_ipv4
        if server_public_tap_vpp_ipv4 is not None:
            self.server_public_tap_vpp_ipv4 = server_public_tap_vpp_ipv4
        if server_agent_status is not None:
            self.server_agent_status = server_agent_status
        if server_agent_key is not None:
            self.server_agent_key = server_agent_key
        if vpn_id is not None:
            self.vpn_id = vpn_id
        if server_skip_configuration is not None:
            self.server_skip_configuration = server_skip_configuration

    @property
    def server_name(self):
        """Gets the server_name of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_name of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_name

    @server_name.setter
    def server_name(self, server_name):
        """Sets the server_name of this TsoaPartialServerObject_.


        :param server_name: The server_name of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_name = server_name

    @property
    def region_id(self):
        """Gets the region_id of this TsoaPartialServerObject_.  # noqa: E501


        :return: The region_id of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: float
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this TsoaPartialServerObject_.


        :param region_id: The region_id of this TsoaPartialServerObject_.  # noqa: E501
        :type: float
        """

        self._region_id = region_id

    @property
    def server_public_ipv4(self):
        """Gets the server_public_ipv4 of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_public_ipv4 of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_public_ipv4

    @server_public_ipv4.setter
    def server_public_ipv4(self, server_public_ipv4):
        """Sets the server_public_ipv4 of this TsoaPartialServerObject_.


        :param server_public_ipv4: The server_public_ipv4 of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_public_ipv4 = server_public_ipv4

    @property
    def server_public_ipv6(self):
        """Gets the server_public_ipv6 of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_public_ipv6 of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_public_ipv6

    @server_public_ipv6.setter
    def server_public_ipv6(self, server_public_ipv6):
        """Sets the server_public_ipv6 of this TsoaPartialServerObject_.


        :param server_public_ipv6: The server_public_ipv6 of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_public_ipv6 = server_public_ipv6

    @property
    def server_config_ipv4(self):
        """Gets the server_config_ipv4 of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_config_ipv4 of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_config_ipv4

    @server_config_ipv4.setter
    def server_config_ipv4(self, server_config_ipv4):
        """Sets the server_config_ipv4 of this TsoaPartialServerObject_.


        :param server_config_ipv4: The server_config_ipv4 of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_config_ipv4 = server_config_ipv4

    @property
    def server_config_ipv6(self):
        """Gets the server_config_ipv6 of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_config_ipv6 of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_config_ipv6

    @server_config_ipv6.setter
    def server_config_ipv6(self, server_config_ipv6):
        """Sets the server_config_ipv6 of this TsoaPartialServerObject_.


        :param server_config_ipv6: The server_config_ipv6 of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_config_ipv6 = server_config_ipv6

    @property
    def server_ipv6_encaps(self):
        """Gets the server_ipv6_encaps of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_ipv6_encaps of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_ipv6_encaps

    @server_ipv6_encaps.setter
    def server_ipv6_encaps(self, server_ipv6_encaps):
        """Sets the server_ipv6_encaps of this TsoaPartialServerObject_.


        :param server_ipv6_encaps: The server_ipv6_encaps of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_ipv6_encaps = server_ipv6_encaps

    @property
    def server_ipv6_start(self):
        """Gets the server_ipv6_start of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_ipv6_start of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_ipv6_start

    @server_ipv6_start.setter
    def server_ipv6_start(self, server_ipv6_start):
        """Sets the server_ipv6_start of this TsoaPartialServerObject_.


        :param server_ipv6_start: The server_ipv6_start of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_ipv6_start = server_ipv6_start

    @property
    def server_ipv6_end(self):
        """Gets the server_ipv6_end of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_ipv6_end of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_ipv6_end

    @server_ipv6_end.setter
    def server_ipv6_end(self, server_ipv6_end):
        """Sets the server_ipv6_end of this TsoaPartialServerObject_.


        :param server_ipv6_end: The server_ipv6_end of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_ipv6_end = server_ipv6_end

    @property
    def server_ipv6_serialized(self):
        """Gets the server_ipv6_serialized of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_ipv6_serialized of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: list[str]
        """
        return self._server_ipv6_serialized

    @server_ipv6_serialized.setter
    def server_ipv6_serialized(self, server_ipv6_serialized):
        """Sets the server_ipv6_serialized of this TsoaPartialServerObject_.


        :param server_ipv6_serialized: The server_ipv6_serialized of this TsoaPartialServerObject_.  # noqa: E501
        :type: list[str]
        """

        self._server_ipv6_serialized = server_ipv6_serialized

    @property
    def server_gateway_ipv4(self):
        """Gets the server_gateway_ipv4 of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_gateway_ipv4 of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_gateway_ipv4

    @server_gateway_ipv4.setter
    def server_gateway_ipv4(self, server_gateway_ipv4):
        """Sets the server_gateway_ipv4 of this TsoaPartialServerObject_.


        :param server_gateway_ipv4: The server_gateway_ipv4 of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_gateway_ipv4 = server_gateway_ipv4

    @property
    def server_gateway_ipv6(self):
        """Gets the server_gateway_ipv6 of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_gateway_ipv6 of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_gateway_ipv6

    @server_gateway_ipv6.setter
    def server_gateway_ipv6(self, server_gateway_ipv6):
        """Sets the server_gateway_ipv6 of this TsoaPartialServerObject_.


        :param server_gateway_ipv6: The server_gateway_ipv6 of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_gateway_ipv6 = server_gateway_ipv6

    @property
    def provider_id(self):
        """Gets the provider_id of this TsoaPartialServerObject_.  # noqa: E501


        :return: The provider_id of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: float
        """
        return self._provider_id

    @provider_id.setter
    def provider_id(self, provider_id):
        """Sets the provider_id of this TsoaPartialServerObject_.


        :param provider_id: The provider_id of this TsoaPartialServerObject_.  # noqa: E501
        :type: float
        """

        self._provider_id = provider_id

    @property
    def topology_id(self):
        """Gets the topology_id of this TsoaPartialServerObject_.  # noqa: E501


        :return: The topology_id of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: float
        """
        return self._topology_id

    @topology_id.setter
    def topology_id(self, topology_id):
        """Sets the topology_id of this TsoaPartialServerObject_.


        :param topology_id: The topology_id of this TsoaPartialServerObject_.  # noqa: E501
        :type: float
        """

        self._topology_id = topology_id

    @property
    def server_sr_software(self):
        """Gets the server_sr_software of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_sr_software of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: ServerSrSoftware
        """
        return self._server_sr_software

    @server_sr_software.setter
    def server_sr_software(self, server_sr_software):
        """Sets the server_sr_software of this TsoaPartialServerObject_.


        :param server_sr_software: The server_sr_software of this TsoaPartialServerObject_.  # noqa: E501
        :type: ServerSrSoftware
        """

        self._server_sr_software = server_sr_software

    @property
    def server_is_transit(self):
        """Gets the server_is_transit of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_is_transit of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: bool
        """
        return self._server_is_transit

    @server_is_transit.setter
    def server_is_transit(self, server_is_transit):
        """Sets the server_is_transit of this TsoaPartialServerObject_.


        :param server_is_transit: The server_is_transit of this TsoaPartialServerObject_.  # noqa: E501
        :type: bool
        """

        self._server_is_transit = server_is_transit

    @property
    def server_is_edge(self):
        """Gets the server_is_edge of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_is_edge of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: bool
        """
        return self._server_is_edge

    @server_is_edge.setter
    def server_is_edge(self, server_is_edge):
        """Sets the server_is_edge of this TsoaPartialServerObject_.


        :param server_is_edge: The server_is_edge of this TsoaPartialServerObject_.  # noqa: E501
        :type: bool
        """

        self._server_is_edge = server_is_edge

    @property
    def server_status(self):
        """Gets the server_status of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_status of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: Status
        """
        return self._server_status

    @server_status.setter
    def server_status(self, server_status):
        """Sets the server_status of this TsoaPartialServerObject_.


        :param server_status: The server_status of this TsoaPartialServerObject_.  # noqa: E501
        :type: Status
        """

        self._server_status = server_status

    @property
    def server_status_reason(self):
        """Gets the server_status_reason of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_status_reason of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_status_reason

    @server_status_reason.setter
    def server_status_reason(self, server_status_reason):
        """Sets the server_status_reason of this TsoaPartialServerObject_.


        :param server_status_reason: The server_status_reason of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_status_reason = server_status_reason

    @property
    def server_location_lat(self):
        """Gets the server_location_lat of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_location_lat of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: float
        """
        return self._server_location_lat

    @server_location_lat.setter
    def server_location_lat(self, server_location_lat):
        """Sets the server_location_lat of this TsoaPartialServerObject_.


        :param server_location_lat: The server_location_lat of this TsoaPartialServerObject_.  # noqa: E501
        :type: float
        """

        self._server_location_lat = server_location_lat

    @property
    def server_location_lon(self):
        """Gets the server_location_lon of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_location_lon of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: float
        """
        return self._server_location_lon

    @server_location_lon.setter
    def server_location_lon(self, server_location_lon):
        """Sets the server_location_lon of this TsoaPartialServerObject_.


        :param server_location_lon: The server_location_lon of this TsoaPartialServerObject_.  # noqa: E501
        :type: float
        """

        self._server_location_lon = server_location_lon

    @property
    def server_location_city(self):
        """Gets the server_location_city of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_location_city of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_location_city

    @server_location_city.setter
    def server_location_city(self, server_location_city):
        """Sets the server_location_city of this TsoaPartialServerObject_.


        :param server_location_city: The server_location_city of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_location_city = server_location_city

    @property
    def server_proxy_required(self):
        """Gets the server_proxy_required of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_proxy_required of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: bool
        """
        return self._server_proxy_required

    @server_proxy_required.setter
    def server_proxy_required(self, server_proxy_required):
        """Sets the server_proxy_required of this TsoaPartialServerObject_.


        :param server_proxy_required: The server_proxy_required of this TsoaPartialServerObject_.  # noqa: E501
        :type: bool
        """

        self._server_proxy_required = server_proxy_required

    @property
    def server_tap_ipv4_cidr(self):
        """Gets the server_tap_ipv4_cidr of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_tap_ipv4_cidr of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_tap_ipv4_cidr

    @server_tap_ipv4_cidr.setter
    def server_tap_ipv4_cidr(self, server_tap_ipv4_cidr):
        """Sets the server_tap_ipv4_cidr of this TsoaPartialServerObject_.


        :param server_tap_ipv4_cidr: The server_tap_ipv4_cidr of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_tap_ipv4_cidr = server_tap_ipv4_cidr

    @property
    def server_tap_host_ipv4_cidr(self):
        """Gets the server_tap_host_ipv4_cidr of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_tap_host_ipv4_cidr of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_tap_host_ipv4_cidr

    @server_tap_host_ipv4_cidr.setter
    def server_tap_host_ipv4_cidr(self, server_tap_host_ipv4_cidr):
        """Sets the server_tap_host_ipv4_cidr of this TsoaPartialServerObject_.


        :param server_tap_host_ipv4_cidr: The server_tap_host_ipv4_cidr of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_tap_host_ipv4_cidr = server_tap_host_ipv4_cidr

    @property
    def server_tap_host_bridge(self):
        """Gets the server_tap_host_bridge of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_tap_host_bridge of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_tap_host_bridge

    @server_tap_host_bridge.setter
    def server_tap_host_bridge(self, server_tap_host_bridge):
        """Sets the server_tap_host_bridge of this TsoaPartialServerObject_.


        :param server_tap_host_bridge: The server_tap_host_bridge of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_tap_host_bridge = server_tap_host_bridge

    @property
    def server_public_tap_host_ipv4(self):
        """Gets the server_public_tap_host_ipv4 of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_public_tap_host_ipv4 of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_public_tap_host_ipv4

    @server_public_tap_host_ipv4.setter
    def server_public_tap_host_ipv4(self, server_public_tap_host_ipv4):
        """Sets the server_public_tap_host_ipv4 of this TsoaPartialServerObject_.


        :param server_public_tap_host_ipv4: The server_public_tap_host_ipv4 of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_public_tap_host_ipv4 = server_public_tap_host_ipv4

    @property
    def server_public_tap_vpp_ipv4(self):
        """Gets the server_public_tap_vpp_ipv4 of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_public_tap_vpp_ipv4 of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_public_tap_vpp_ipv4

    @server_public_tap_vpp_ipv4.setter
    def server_public_tap_vpp_ipv4(self, server_public_tap_vpp_ipv4):
        """Sets the server_public_tap_vpp_ipv4 of this TsoaPartialServerObject_.


        :param server_public_tap_vpp_ipv4: The server_public_tap_vpp_ipv4 of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_public_tap_vpp_ipv4 = server_public_tap_vpp_ipv4

    @property
    def server_agent_status(self):
        """Gets the server_agent_status of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_agent_status of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: ServerAgentStatus
        """
        return self._server_agent_status

    @server_agent_status.setter
    def server_agent_status(self, server_agent_status):
        """Sets the server_agent_status of this TsoaPartialServerObject_.


        :param server_agent_status: The server_agent_status of this TsoaPartialServerObject_.  # noqa: E501
        :type: ServerAgentStatus
        """

        self._server_agent_status = server_agent_status

    @property
    def server_agent_key(self):
        """Gets the server_agent_key of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_agent_key of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: str
        """
        return self._server_agent_key

    @server_agent_key.setter
    def server_agent_key(self, server_agent_key):
        """Sets the server_agent_key of this TsoaPartialServerObject_.


        :param server_agent_key: The server_agent_key of this TsoaPartialServerObject_.  # noqa: E501
        :type: str
        """

        self._server_agent_key = server_agent_key

    @property
    def vpn_id(self):
        """Gets the vpn_id of this TsoaPartialServerObject_.  # noqa: E501


        :return: The vpn_id of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: float
        """
        return self._vpn_id

    @vpn_id.setter
    def vpn_id(self, vpn_id):
        """Sets the vpn_id of this TsoaPartialServerObject_.


        :param vpn_id: The vpn_id of this TsoaPartialServerObject_.  # noqa: E501
        :type: float
        """

        self._vpn_id = vpn_id

    @property
    def server_skip_configuration(self):
        """Gets the server_skip_configuration of this TsoaPartialServerObject_.  # noqa: E501


        :return: The server_skip_configuration of this TsoaPartialServerObject_.  # noqa: E501
        :rtype: bool
        """
        return self._server_skip_configuration

    @server_skip_configuration.setter
    def server_skip_configuration(self, server_skip_configuration):
        """Sets the server_skip_configuration of this TsoaPartialServerObject_.


        :param server_skip_configuration: The server_skip_configuration of this TsoaPartialServerObject_.  # noqa: E501
        :type: bool
        """

        self._server_skip_configuration = server_skip_configuration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialServerObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialServerObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class VppCallableObjectArgs7(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "endpoints": "list[str]",
        "port": "float",
        "addr": "str",
        "ifname": "str",
    }

    attribute_map = {
        "endpoints": "endpoints",
        "port": "port",
        "addr": "addr",
        "ifname": "ifname",
    }

    def __init__(self, endpoints=None, port=None, addr=None, ifname=None):  # noqa: E501
        """VppCallableObjectArgs7 - a model defined in Swagger"""  # noqa: E501
        self._endpoints = None
        self._port = None
        self._addr = None
        self._ifname = None
        self.discriminator = None
        self.endpoints = endpoints
        self.port = port
        if addr is not None:
            self.addr = addr
        self.ifname = ifname

    @property
    def endpoints(self):
        """Gets the endpoints of this VppCallableObjectArgs7.  # noqa: E501


        :return: The endpoints of this VppCallableObjectArgs7.  # noqa: E501
        :rtype: list[str]
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """Sets the endpoints of this VppCallableObjectArgs7.


        :param endpoints: The endpoints of this VppCallableObjectArgs7.  # noqa: E501
        :type: list[str]
        """
        if endpoints is None:
            raise ValueError(
                "Invalid value for `endpoints`, must not be `None`"
            )  # noqa: E501

        self._endpoints = endpoints

    @property
    def port(self):
        """Gets the port of this VppCallableObjectArgs7.  # noqa: E501


        :return: The port of this VppCallableObjectArgs7.  # noqa: E501
        :rtype: float
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this VppCallableObjectArgs7.


        :param port: The port of this VppCallableObjectArgs7.  # noqa: E501
        :type: float
        """
        if port is None:
            raise ValueError(
                "Invalid value for `port`, must not be `None`"
            )  # noqa: E501

        self._port = port

    @property
    def addr(self):
        """Gets the addr of this VppCallableObjectArgs7.  # noqa: E501


        :return: The addr of this VppCallableObjectArgs7.  # noqa: E501
        :rtype: str
        """
        return self._addr

    @addr.setter
    def addr(self, addr):
        """Sets the addr of this VppCallableObjectArgs7.


        :param addr: The addr of this VppCallableObjectArgs7.  # noqa: E501
        :type: str
        """

        self._addr = addr

    @property
    def ifname(self):
        """Gets the ifname of this VppCallableObjectArgs7.  # noqa: E501


        :return: The ifname of this VppCallableObjectArgs7.  # noqa: E501
        :rtype: str
        """
        return self._ifname

    @ifname.setter
    def ifname(self, ifname):
        """Sets the ifname of this VppCallableObjectArgs7.


        :param ifname: The ifname of this VppCallableObjectArgs7.  # noqa: E501
        :type: str
        """
        if ifname is None:
            raise ValueError(
                "Invalid value for `ifname`, must not be `None`"
            )  # noqa: E501

        self._ifname = ifname

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(VppCallableObjectArgs7, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VppCallableObjectArgs7):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-auth-service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class UserSettingsObject(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "show_onboarding": "bool",
        "show_registration_form": "bool",
        "user_timezone": "str",
        "auth_sources": "list[AuthSource]",
        "network_disable_sdn_connections": "bool",
        "two_factors_authentication": "bool",
    }

    attribute_map = {
        "show_onboarding": "show_onboarding",
        "show_registration_form": "show_registration_form",
        "user_timezone": "user_timezone",
        "auth_sources": "auth_sources",
        "network_disable_sdn_connections": "network_disable_sdn_connections",
        "two_factors_authentication": "two_factors_authentication",
    }

    def __init__(
        self,
        show_onboarding=None,
        show_registration_form=None,
        user_timezone=None,
        auth_sources=None,
        network_disable_sdn_connections=None,
        two_factors_authentication=None,
    ):  # noqa: E501
        """UserSettingsObject - a model defined in Swagger"""  # noqa: E501
        self._show_onboarding = None
        self._show_registration_form = None
        self._user_timezone = None
        self._auth_sources = None
        self._network_disable_sdn_connections = None
        self._two_factors_authentication = None
        self.discriminator = None
        if show_onboarding is not None:
            self.show_onboarding = show_onboarding
        if show_registration_form is not None:
            self.show_registration_form = show_registration_form
        if user_timezone is not None:
            self.user_timezone = user_timezone
        if auth_sources is not None:
            self.auth_sources = auth_sources
        if network_disable_sdn_connections is not None:
            self.network_disable_sdn_connections = network_disable_sdn_connections
        if two_factors_authentication is not None:
            self.two_factors_authentication = two_factors_authentication

    @property
    def show_onboarding(self):
        """Gets the show_onboarding of this UserSettingsObject.  # noqa: E501


        :return: The show_onboarding of this UserSettingsObject.  # noqa: E501
        :rtype: bool
        """
        return self._show_onboarding

    @show_onboarding.setter
    def show_onboarding(self, show_onboarding):
        """Sets the show_onboarding of this UserSettingsObject.


        :param show_onboarding: The show_onboarding of this UserSettingsObject.  # noqa: E501
        :type: bool
        """

        self._show_onboarding = show_onboarding

    @property
    def show_registration_form(self):
        """Gets the show_registration_form of this UserSettingsObject.  # noqa: E501


        :return: The show_registration_form of this UserSettingsObject.  # noqa: E501
        :rtype: bool
        """
        return self._show_registration_form

    @show_registration_form.setter
    def show_registration_form(self, show_registration_form):
        """Sets the show_registration_form of this UserSettingsObject.


        :param show_registration_form: The show_registration_form of this UserSettingsObject.  # noqa: E501
        :type: bool
        """

        self._show_registration_form = show_registration_form

    @property
    def user_timezone(self):
        """Gets the user_timezone of this UserSettingsObject.  # noqa: E501


        :return: The user_timezone of this UserSettingsObject.  # noqa: E501
        :rtype: str
        """
        return self._user_timezone

    @user_timezone.setter
    def user_timezone(self, user_timezone):
        """Sets the user_timezone of this UserSettingsObject.


        :param user_timezone: The user_timezone of this UserSettingsObject.  # noqa: E501
        :type: str
        """

        self._user_timezone = user_timezone

    @property
    def auth_sources(self):
        """Gets the auth_sources of this UserSettingsObject.  # noqa: E501


        :return: The auth_sources of this UserSettingsObject.  # noqa: E501
        :rtype: list[AuthSource]
        """
        return self._auth_sources

    @auth_sources.setter
    def auth_sources(self, auth_sources):
        """Sets the auth_sources of this UserSettingsObject.


        :param auth_sources: The auth_sources of this UserSettingsObject.  # noqa: E501
        :type: list[AuthSource]
        """

        self._auth_sources = auth_sources

    @property
    def network_disable_sdn_connections(self):
        """Gets the network_disable_sdn_connections of this UserSettingsObject.  # noqa: E501


        :return: The network_disable_sdn_connections of this UserSettingsObject.  # noqa: E501
        :rtype: bool
        """
        return self._network_disable_sdn_connections

    @network_disable_sdn_connections.setter
    def network_disable_sdn_connections(self, network_disable_sdn_connections):
        """Sets the network_disable_sdn_connections of this UserSettingsObject.


        :param network_disable_sdn_connections: The network_disable_sdn_connections of this UserSettingsObject.  # noqa: E501
        :type: bool
        """

        self._network_disable_sdn_connections = network_disable_sdn_connections

    @property
    def two_factors_authentication(self):
        """Gets the two_factors_authentication of this UserSettingsObject.  # noqa: E501


        :return: The two_factors_authentication of this UserSettingsObject.  # noqa: E501
        :rtype: bool
        """
        return self._two_factors_authentication

    @two_factors_authentication.setter
    def two_factors_authentication(self, two_factors_authentication):
        """Sets the two_factors_authentication of this UserSettingsObject.


        :param two_factors_authentication: The two_factors_authentication of this UserSettingsObject.  # noqa: E501
        :type: bool
        """

        self._two_factors_authentication = two_factors_authentication

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSettingsObject, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSettingsObject):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-auth-service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ContactRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "name": "str",
        "company": "str",
        "domain": "str",
        "marketing_email_agreed": "bool",
    }

    attribute_map = {
        "name": "name",
        "company": "company",
        "domain": "domain",
        "marketing_email_agreed": "marketing_email_agreed",
    }

    def __init__(
        self, name=None, company=None, domain=None, marketing_email_agreed=None
    ):  # noqa: E501
        """ContactRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._company = None
        self._domain = None
        self._marketing_email_agreed = None
        self.discriminator = None
        self.name = name
        if company is not None:
            self.company = company
        self.domain = domain
        self.marketing_email_agreed = marketing_email_agreed

    @property
    def name(self):
        """Gets the name of this ContactRequest.  # noqa: E501


        :return: The name of this ContactRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ContactRequest.


        :param name: The name of this ContactRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def company(self):
        """Gets the company of this ContactRequest.  # noqa: E501


        :return: The company of this ContactRequest.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this ContactRequest.


        :param company: The company of this ContactRequest.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def domain(self):
        """Gets the domain of this ContactRequest.  # noqa: E501


        :return: The domain of this ContactRequest.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this ContactRequest.


        :param domain: The domain of this ContactRequest.  # noqa: E501
        :type: str
        """
        if domain is None:
            raise ValueError(
                "Invalid value for `domain`, must not be `None`"
            )  # noqa: E501

        self._domain = domain

    @property
    def marketing_email_agreed(self):
        """Gets the marketing_email_agreed of this ContactRequest.  # noqa: E501


        :return: The marketing_email_agreed of this ContactRequest.  # noqa: E501
        :rtype: bool
        """
        return self._marketing_email_agreed

    @marketing_email_agreed.setter
    def marketing_email_agreed(self, marketing_email_agreed):
        """Sets the marketing_email_agreed of this ContactRequest.


        :param marketing_email_agreed: The marketing_email_agreed of this ContactRequest.  # noqa: E501
        :type: bool
        """
        if marketing_email_agreed is None:
            raise ValueError(
                "Invalid value for `marketing_email_agreed`, must not be `None`"
            )  # noqa: E501

        self._marketing_email_agreed = marketing_email_agreed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ContactRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContactRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# import apis into api package
from syntropy_sdk.api.api_keys_api import ApiKeysApi
from syntropy_sdk.api.auth_api import AuthApi
from syntropy_sdk.api.platform_api import PlatformApi

# flake8: noqa



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialVpnObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "ingress_server_id": "float",
        "vpn_internal_ipv4": "str",
        "vpn_public_key": "str",
        "vpn_endpoint_ip": "str",
        "vpn_gateway_ipv4": "str",
        "vpn_interface_ip": "str",
    }

    attribute_map = {
        "ingress_server_id": "ingress_server_id",
        "vpn_internal_ipv4": "vpn_internal_ipv4",
        "vpn_public_key": "vpn_public_key",
        "vpn_endpoint_ip": "vpn_endpoint_ip",
        "vpn_gateway_ipv4": "vpn_gateway_ipv4",
        "vpn_interface_ip": "vpn_interface_ip",
    }

    def __init__(
        self,
        ingress_server_id=None,
        vpn_internal_ipv4=None,
        vpn_public_key=None,
        vpn_endpoint_ip=None,
        vpn_gateway_ipv4=None,
        vpn_interface_ip=None,
    ):  # noqa: E501
        """TsoaPartialVpnObject_ - a model defined in Swagger"""  # noqa: E501
        self._ingress_server_id = None
        self._vpn_internal_ipv4 = None
        self._vpn_public_key = None
        self._vpn_endpoint_ip = None
        self._vpn_gateway_ipv4 = None
        self._vpn_interface_ip = None
        self.discriminator = None
        if ingress_server_id is not None:
            self.ingress_server_id = ingress_server_id
        if vpn_internal_ipv4 is not None:
            self.vpn_internal_ipv4 = vpn_internal_ipv4
        if vpn_public_key is not None:
            self.vpn_public_key = vpn_public_key
        if vpn_endpoint_ip is not None:
            self.vpn_endpoint_ip = vpn_endpoint_ip
        if vpn_gateway_ipv4 is not None:
            self.vpn_gateway_ipv4 = vpn_gateway_ipv4
        if vpn_interface_ip is not None:
            self.vpn_interface_ip = vpn_interface_ip

    @property
    def ingress_server_id(self):
        """Gets the ingress_server_id of this TsoaPartialVpnObject_.  # noqa: E501


        :return: The ingress_server_id of this TsoaPartialVpnObject_.  # noqa: E501
        :rtype: float
        """
        return self._ingress_server_id

    @ingress_server_id.setter
    def ingress_server_id(self, ingress_server_id):
        """Sets the ingress_server_id of this TsoaPartialVpnObject_.


        :param ingress_server_id: The ingress_server_id of this TsoaPartialVpnObject_.  # noqa: E501
        :type: float
        """

        self._ingress_server_id = ingress_server_id

    @property
    def vpn_internal_ipv4(self):
        """Gets the vpn_internal_ipv4 of this TsoaPartialVpnObject_.  # noqa: E501


        :return: The vpn_internal_ipv4 of this TsoaPartialVpnObject_.  # noqa: E501
        :rtype: str
        """
        return self._vpn_internal_ipv4

    @vpn_internal_ipv4.setter
    def vpn_internal_ipv4(self, vpn_internal_ipv4):
        """Sets the vpn_internal_ipv4 of this TsoaPartialVpnObject_.


        :param vpn_internal_ipv4: The vpn_internal_ipv4 of this TsoaPartialVpnObject_.  # noqa: E501
        :type: str
        """

        self._vpn_internal_ipv4 = vpn_internal_ipv4

    @property
    def vpn_public_key(self):
        """Gets the vpn_public_key of this TsoaPartialVpnObject_.  # noqa: E501


        :return: The vpn_public_key of this TsoaPartialVpnObject_.  # noqa: E501
        :rtype: str
        """
        return self._vpn_public_key

    @vpn_public_key.setter
    def vpn_public_key(self, vpn_public_key):
        """Sets the vpn_public_key of this TsoaPartialVpnObject_.


        :param vpn_public_key: The vpn_public_key of this TsoaPartialVpnObject_.  # noqa: E501
        :type: str
        """

        self._vpn_public_key = vpn_public_key

    @property
    def vpn_endpoint_ip(self):
        """Gets the vpn_endpoint_ip of this TsoaPartialVpnObject_.  # noqa: E501


        :return: The vpn_endpoint_ip of this TsoaPartialVpnObject_.  # noqa: E501
        :rtype: str
        """
        return self._vpn_endpoint_ip

    @vpn_endpoint_ip.setter
    def vpn_endpoint_ip(self, vpn_endpoint_ip):
        """Sets the vpn_endpoint_ip of this TsoaPartialVpnObject_.


        :param vpn_endpoint_ip: The vpn_endpoint_ip of this TsoaPartialVpnObject_.  # noqa: E501
        :type: str
        """

        self._vpn_endpoint_ip = vpn_endpoint_ip

    @property
    def vpn_gateway_ipv4(self):
        """Gets the vpn_gateway_ipv4 of this TsoaPartialVpnObject_.  # noqa: E501


        :return: The vpn_gateway_ipv4 of this TsoaPartialVpnObject_.  # noqa: E501
        :rtype: str
        """
        return self._vpn_gateway_ipv4

    @vpn_gateway_ipv4.setter
    def vpn_gateway_ipv4(self, vpn_gateway_ipv4):
        """Sets the vpn_gateway_ipv4 of this TsoaPartialVpnObject_.


        :param vpn_gateway_ipv4: The vpn_gateway_ipv4 of this TsoaPartialVpnObject_.  # noqa: E501
        :type: str
        """

        self._vpn_gateway_ipv4 = vpn_gateway_ipv4

    @property
    def vpn_interface_ip(self):
        """Gets the vpn_interface_ip of this TsoaPartialVpnObject_.  # noqa: E501


        :return: The vpn_interface_ip of this TsoaPartialVpnObject_.  # noqa: E501
        :rtype: str
        """
        return self._vpn_interface_ip

    @vpn_interface_ip.setter
    def vpn_interface_ip(self, vpn_interface_ip):
        """Sets the vpn_interface_ip of this TsoaPartialVpnObject_.


        :param vpn_interface_ip: The vpn_interface_ip of this TsoaPartialVpnObject_.  # noqa: E501
        :type: str
        """

        self._vpn_interface_ip = vpn_interface_ip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialVpnObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialVpnObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class WgCreateInterfaceArgs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "public_key": "str",
        "listen_port": "float",
        "internal_ip": "str",
        "ifname": "str",
    }

    attribute_map = {
        "public_key": "public_key",
        "listen_port": "listen_port",
        "internal_ip": "internal_ip",
        "ifname": "ifname",
    }

    def __init__(
        self, public_key=None, listen_port=None, internal_ip=None, ifname=None
    ):  # noqa: E501
        """WgCreateInterfaceArgs - a model defined in Swagger"""  # noqa: E501
        self._public_key = None
        self._listen_port = None
        self._internal_ip = None
        self._ifname = None
        self.discriminator = None
        if public_key is not None:
            self.public_key = public_key
        if listen_port is not None:
            self.listen_port = listen_port
        self.internal_ip = internal_ip
        self.ifname = ifname

    @property
    def public_key(self):
        """Gets the public_key of this WgCreateInterfaceArgs.  # noqa: E501


        :return: The public_key of this WgCreateInterfaceArgs.  # noqa: E501
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """Sets the public_key of this WgCreateInterfaceArgs.


        :param public_key: The public_key of this WgCreateInterfaceArgs.  # noqa: E501
        :type: str
        """

        self._public_key = public_key

    @property
    def listen_port(self):
        """Gets the listen_port of this WgCreateInterfaceArgs.  # noqa: E501


        :return: The listen_port of this WgCreateInterfaceArgs.  # noqa: E501
        :rtype: float
        """
        return self._listen_port

    @listen_port.setter
    def listen_port(self, listen_port):
        """Sets the listen_port of this WgCreateInterfaceArgs.


        :param listen_port: The listen_port of this WgCreateInterfaceArgs.  # noqa: E501
        :type: float
        """

        self._listen_port = listen_port

    @property
    def internal_ip(self):
        """Gets the internal_ip of this WgCreateInterfaceArgs.  # noqa: E501


        :return: The internal_ip of this WgCreateInterfaceArgs.  # noqa: E501
        :rtype: str
        """
        return self._internal_ip

    @internal_ip.setter
    def internal_ip(self, internal_ip):
        """Sets the internal_ip of this WgCreateInterfaceArgs.


        :param internal_ip: The internal_ip of this WgCreateInterfaceArgs.  # noqa: E501
        :type: str
        """
        if internal_ip is None:
            raise ValueError(
                "Invalid value for `internal_ip`, must not be `None`"
            )  # noqa: E501

        self._internal_ip = internal_ip

    @property
    def ifname(self):
        """Gets the ifname of this WgCreateInterfaceArgs.  # noqa: E501


        :return: The ifname of this WgCreateInterfaceArgs.  # noqa: E501
        :rtype: str
        """
        return self._ifname

    @ifname.setter
    def ifname(self, ifname):
        """Sets the ifname of this WgCreateInterfaceArgs.


        :param ifname: The ifname of this WgCreateInterfaceArgs.  # noqa: E501
        :type: str
        """
        if ifname is None:
            raise ValueError(
                "Invalid value for `ifname`, must not be `None`"
            )  # noqa: E501

        self._ifname = ifname

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(WgCreateInterfaceArgs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WgCreateInterfaceArgs):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-auth-service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class UserDataResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "user_id": "float",
        "user_email": "str",
        "user_settings": "UserSettingsObject",
        "user_scopes": "list[str]",
    }

    attribute_map = {
        "user_id": "user_id",
        "user_email": "user_email",
        "user_settings": "user_settings",
        "user_scopes": "user_scopes",
    }

    def __init__(
        self, user_id=None, user_email=None, user_settings=None, user_scopes=None
    ):  # noqa: E501
        """UserDataResponse - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._user_email = None
        self._user_settings = None
        self._user_scopes = None
        self.discriminator = None
        self.user_id = user_id
        self.user_email = user_email
        self.user_settings = user_settings
        self.user_scopes = user_scopes

    @property
    def user_id(self):
        """Gets the user_id of this UserDataResponse.  # noqa: E501


        :return: The user_id of this UserDataResponse.  # noqa: E501
        :rtype: float
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserDataResponse.


        :param user_id: The user_id of this UserDataResponse.  # noqa: E501
        :type: float
        """
        if user_id is None:
            raise ValueError(
                "Invalid value for `user_id`, must not be `None`"
            )  # noqa: E501

        self._user_id = user_id

    @property
    def user_email(self):
        """Gets the user_email of this UserDataResponse.  # noqa: E501


        :return: The user_email of this UserDataResponse.  # noqa: E501
        :rtype: str
        """
        return self._user_email

    @user_email.setter
    def user_email(self, user_email):
        """Sets the user_email of this UserDataResponse.


        :param user_email: The user_email of this UserDataResponse.  # noqa: E501
        :type: str
        """
        if user_email is None:
            raise ValueError(
                "Invalid value for `user_email`, must not be `None`"
            )  # noqa: E501

        self._user_email = user_email

    @property
    def user_settings(self):
        """Gets the user_settings of this UserDataResponse.  # noqa: E501


        :return: The user_settings of this UserDataResponse.  # noqa: E501
        :rtype: UserSettingsObject
        """
        return self._user_settings

    @user_settings.setter
    def user_settings(self, user_settings):
        """Sets the user_settings of this UserDataResponse.


        :param user_settings: The user_settings of this UserDataResponse.  # noqa: E501
        :type: UserSettingsObject
        """
        if user_settings is None:
            raise ValueError(
                "Invalid value for `user_settings`, must not be `None`"
            )  # noqa: E501

        self._user_settings = user_settings

    @property
    def user_scopes(self):
        """Gets the user_scopes of this UserDataResponse.  # noqa: E501


        :return: The user_scopes of this UserDataResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_scopes

    @user_scopes.setter
    def user_scopes(self, user_scopes):
        """Sets the user_scopes of this UserDataResponse.


        :param user_scopes: The user_scopes of this UserDataResponse.  # noqa: E501
        :type: list[str]
        """
        if user_scopes is None:
            raise ValueError(
                "Invalid value for `user_scopes`, must not be `None`"
            )  # noqa: E501

        self._user_scopes = user_scopes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserDataResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserDataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialTranslationObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "lang_id": "float",
        "translation_key": "str",
        "translation_value": "str",
        "translation_type": "ContextType",
        "translation_visibility": "VisibilityType",
    }

    attribute_map = {
        "lang_id": "lang_id",
        "translation_key": "translation_key",
        "translation_value": "translation_value",
        "translation_type": "translation_type",
        "translation_visibility": "translation_visibility",
    }

    def __init__(
        self,
        lang_id=None,
        translation_key=None,
        translation_value=None,
        translation_type=None,
        translation_visibility=None,
    ):  # noqa: E501
        """TsoaPartialTranslationObject_ - a model defined in Swagger"""  # noqa: E501
        self._lang_id = None
        self._translation_key = None
        self._translation_value = None
        self._translation_type = None
        self._translation_visibility = None
        self.discriminator = None
        if lang_id is not None:
            self.lang_id = lang_id
        if translation_key is not None:
            self.translation_key = translation_key
        if translation_value is not None:
            self.translation_value = translation_value
        if translation_type is not None:
            self.translation_type = translation_type
        if translation_visibility is not None:
            self.translation_visibility = translation_visibility

    @property
    def lang_id(self):
        """Gets the lang_id of this TsoaPartialTranslationObject_.  # noqa: E501


        :return: The lang_id of this TsoaPartialTranslationObject_.  # noqa: E501
        :rtype: float
        """
        return self._lang_id

    @lang_id.setter
    def lang_id(self, lang_id):
        """Sets the lang_id of this TsoaPartialTranslationObject_.


        :param lang_id: The lang_id of this TsoaPartialTranslationObject_.  # noqa: E501
        :type: float
        """

        self._lang_id = lang_id

    @property
    def translation_key(self):
        """Gets the translation_key of this TsoaPartialTranslationObject_.  # noqa: E501


        :return: The translation_key of this TsoaPartialTranslationObject_.  # noqa: E501
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """Sets the translation_key of this TsoaPartialTranslationObject_.


        :param translation_key: The translation_key of this TsoaPartialTranslationObject_.  # noqa: E501
        :type: str
        """

        self._translation_key = translation_key

    @property
    def translation_value(self):
        """Gets the translation_value of this TsoaPartialTranslationObject_.  # noqa: E501


        :return: The translation_value of this TsoaPartialTranslationObject_.  # noqa: E501
        :rtype: str
        """
        return self._translation_value

    @translation_value.setter
    def translation_value(self, translation_value):
        """Sets the translation_value of this TsoaPartialTranslationObject_.


        :param translation_value: The translation_value of this TsoaPartialTranslationObject_.  # noqa: E501
        :type: str
        """

        self._translation_value = translation_value

    @property
    def translation_type(self):
        """Gets the translation_type of this TsoaPartialTranslationObject_.  # noqa: E501


        :return: The translation_type of this TsoaPartialTranslationObject_.  # noqa: E501
        :rtype: ContextType
        """
        return self._translation_type

    @translation_type.setter
    def translation_type(self, translation_type):
        """Sets the translation_type of this TsoaPartialTranslationObject_.


        :param translation_type: The translation_type of this TsoaPartialTranslationObject_.  # noqa: E501
        :type: ContextType
        """

        self._translation_type = translation_type

    @property
    def translation_visibility(self):
        """Gets the translation_visibility of this TsoaPartialTranslationObject_.  # noqa: E501


        :return: The translation_visibility of this TsoaPartialTranslationObject_.  # noqa: E501
        :rtype: VisibilityType
        """
        return self._translation_visibility

    @translation_visibility.setter
    def translation_visibility(self, translation_visibility):
        """Sets the translation_visibility of this TsoaPartialTranslationObject_.


        :param translation_visibility: The translation_visibility of this TsoaPartialTranslationObject_.  # noqa: E501
        :type: VisibilityType
        """

        self._translation_visibility = translation_visibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialTranslationObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialTranslationObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
